from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.judge import announcement_service_pb2 as _announcement_service_pb2
from eolymp.judge import contest_service_pb2 as _contest_service_pb2
from eolymp.judge import participant_service_pb2 as _participant_service_pb2
from eolymp.judge import passcode_service_pb2 as _passcode_service_pb2
from eolymp.judge import problem_service_pb2 as _problem_service_pb2
from eolymp.judge import score_service_pb2 as _score_service_pb2
from eolymp.judge import submission_service_pb2 as _submission_service_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
