# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/testing_checker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import checker_pb2 as eolymp_dot_executor_dot_checker__pb2
from eolymp.executor import file_pb2 as eolymp_dot_executor_dot_file__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/atlas/testing_checker.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/executor/checker.proto\x1a\x1a\x65olymp/executor/file.proto\"\xd1\x01\n\x07\x43hecker\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.eolymp.executor.Checker.Type\x12\x0f\n\x07runtime\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\x12\x11\n\tprecision\x18\x04 \x01(\x05\x12\x16\n\x0e\x63\x61se_sensitive\x18\x05 \x01(\x08\x12\x17\n\x0forder_sensitive\x18\x06 \x01(\x08\x12\x0e\n\x06secret\x18\x07 \x01(\x08\x12$\n\x05\x66iles\x18\n \x03(\x0b\x32\x15.eolymp.executor.FileB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.testing_checker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _CHECKER._serialized_start=112
  _CHECKER._serialized_end=321
# @@protoc_insertion_point(module_scope)
