# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/code_template_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import code_template_pb2 as eolymp_dot_atlas_dot_code__template__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/atlas/code_template_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/atlas/code_template.proto\"C\n\x17\x43reateCodeTemplateInput\x12(\n\x08template\x18\x02 \x01(\x0b\x32\x16.eolymp.atlas.Template\"/\n\x18\x43reateCodeTemplateOutput\x12\x13\n\x0btemplate_id\x18\x01 \x01(\t\"\xb2\x01\n\x17UpdateCodeTemplateInput\x12\x13\n\x0btemplate_id\x18\x02 \x01(\t\x12(\n\x08template\x18\x03 \x01(\x0b\x32\x16.eolymp.atlas.Template\"X\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07RUNTIME\x10\x01\x12\n\n\x06SOURCE\x10\x02\x12\n\n\x06HEADER\x10\x03\x12\n\n\x06\x46OOTER\x10\x04\x12\n\n\x06SECRET\x10\x05\x12\t\n\x05\x46ILES\x10\x06\"\x1a\n\x18UpdateCodeTemplateOutput\".\n\x17\x44\x65leteCodeTemplateInput\x12\x13\n\x0btemplate_id\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteCodeTemplateOutput\")\n\x16ListCodeTemplatesInput\x12\x0f\n\x07version\x18\x64 \x01(\r\"O\n\x17ListCodeTemplatesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.atlas.Template\"A\n\x19\x44\x65scribeCodeTemplateInput\x12\x13\n\x0btemplate_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"F\n\x1a\x44\x65scribeCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Template\"*\n\x17LookupCodeTemplateInput\x12\x0f\n\x07runtime\x18\x02 \x01(\t\"D\n\x18LookupCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Template2\x96\x08\n\x13\x43odeTemplateService\x12\xa1\x01\n\x12\x43reateCodeTemplate\x12%.eolymp.atlas.CreateCodeTemplateInput\x1a&.eolymp.atlas.CreateCodeTemplateOutput\"<\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0c\"\n/templates\x12\xaf\x01\n\x12UpdateCodeTemplate\x12%.eolymp.atlas.UpdateCodeTemplateInput\x1a&.eolymp.atlas.UpdateCodeTemplateOutput\"J\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1a\"\x18/templates/{template_id}\x12\xaf\x01\n\x12\x44\x65leteCodeTemplate\x12%.eolymp.atlas.DeleteCodeTemplateInput\x1a&.eolymp.atlas.DeleteCodeTemplateOutput\"J\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1a*\x18/templates/{template_id}\x12\x9d\x01\n\x11ListCodeTemplates\x12$.eolymp.atlas.ListCodeTemplatesInput\x1a%.eolymp.atlas.ListCodeTemplatesOutput\";\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0c\x12\n/templates\x12\xb4\x01\n\x14\x44\x65scribeCodeTemplate\x12\'.eolymp.atlas.DescribeCodeTemplateInput\x1a(.eolymp.atlas.DescribeCodeTemplateOutput\"I\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1a\x12\x18/templates/{template_id}\x12\x9f\x01\n\x12LookupCodeTemplate\x12%.eolymp.atlas.LookupCodeTemplateInput\x1a&.eolymp.atlas.LookupCodeTemplateOutput\":\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0b\x12\t/templateB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.code_template_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _CODETEMPLATESERVICE.methods_by_name['CreateCodeTemplate']._options = None
  _CODETEMPLATESERVICE.methods_by_name['CreateCodeTemplate']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\014\"\n/templates'
  _CODETEMPLATESERVICE.methods_by_name['UpdateCodeTemplate']._options = None
  _CODETEMPLATESERVICE.methods_by_name['UpdateCodeTemplate']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\032\"\030/templates/{template_id}'
  _CODETEMPLATESERVICE.methods_by_name['DeleteCodeTemplate']._options = None
  _CODETEMPLATESERVICE.methods_by_name['DeleteCodeTemplate']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\032*\030/templates/{template_id}'
  _CODETEMPLATESERVICE.methods_by_name['ListCodeTemplates']._options = None
  _CODETEMPLATESERVICE.methods_by_name['ListCodeTemplates']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\014\022\n/templates'
  _CODETEMPLATESERVICE.methods_by_name['DescribeCodeTemplate']._options = None
  _CODETEMPLATESERVICE.methods_by_name['DescribeCodeTemplate']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\032\022\030/templates/{template_id}'
  _CODETEMPLATESERVICE.methods_by_name['LookupCodeTemplate']._options = None
  _CODETEMPLATESERVICE.methods_by_name['LookupCodeTemplate']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\013\022\t/template'
  _CREATECODETEMPLATEINPUT._serialized_start=191
  _CREATECODETEMPLATEINPUT._serialized_end=258
  _CREATECODETEMPLATEOUTPUT._serialized_start=260
  _CREATECODETEMPLATEOUTPUT._serialized_end=307
  _UPDATECODETEMPLATEINPUT._serialized_start=310
  _UPDATECODETEMPLATEINPUT._serialized_end=488
  _UPDATECODETEMPLATEINPUT_PATCH._serialized_start=400
  _UPDATECODETEMPLATEINPUT_PATCH._serialized_end=488
  _UPDATECODETEMPLATEOUTPUT._serialized_start=490
  _UPDATECODETEMPLATEOUTPUT._serialized_end=516
  _DELETECODETEMPLATEINPUT._serialized_start=518
  _DELETECODETEMPLATEINPUT._serialized_end=564
  _DELETECODETEMPLATEOUTPUT._serialized_start=566
  _DELETECODETEMPLATEOUTPUT._serialized_end=592
  _LISTCODETEMPLATESINPUT._serialized_start=594
  _LISTCODETEMPLATESINPUT._serialized_end=635
  _LISTCODETEMPLATESOUTPUT._serialized_start=637
  _LISTCODETEMPLATESOUTPUT._serialized_end=716
  _DESCRIBECODETEMPLATEINPUT._serialized_start=718
  _DESCRIBECODETEMPLATEINPUT._serialized_end=783
  _DESCRIBECODETEMPLATEOUTPUT._serialized_start=785
  _DESCRIBECODETEMPLATEOUTPUT._serialized_end=855
  _LOOKUPCODETEMPLATEINPUT._serialized_start=857
  _LOOKUPCODETEMPLATEINPUT._serialized_end=899
  _LOOKUPCODETEMPLATEOUTPUT._serialized_start=901
  _LOOKUPCODETEMPLATEOUTPUT._serialized_end=969
  _CODETEMPLATESERVICE._serialized_start=972
  _CODETEMPLATESERVICE._serialized_end=2018
# @@protoc_insertion_point(module_scope)
