# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/newsletter/recipient_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.newsletter import recipient_pb2 as eolymp_dot_newsletter_dot_recipient__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)eolymp/newsletter/recipient_service.proto\x12\x11\x65olymp.newsletter\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a!eolymp/newsletter/recipient.proto\"G\n\x14\x43reateRecipientInput\x12/\n\trecipient\x18\n \x01(\x0b\x32\x1c.eolymp.newsletter.Recipient\"-\n\x15\x43reateRecipientOutput\x12\x14\n\x0crecipient_id\x18\x01 \x01(\t\"5\n\x15ImportRecipientsInput\x12\x12\n\x08group_id\x18\x0b \x01(\tH\x00\x42\x08\n\x06source\"0\n\x16ImportRecipientsOutput\x12\x16\n\x0eimported_total\x18\x01 \x01(\t\",\n\x14RemoveRecipientInput\x12\x14\n\x0crecipient_id\x18\x02 \x01(\t\"\x17\n\x15RemoveRecipientOutput\"3\n\x13ListRecipientsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"R\n\x14ListRecipientsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12+\n\x05items\x18\x02 \x03(\x0b\x32\x1c.eolymp.newsletter.Recipient\".\n\x16\x44\x65scribeRecipientInput\x12\x14\n\x0crecipient_id\x18\x01 \x01(\t\"J\n\x17\x44\x65scribeRecipientOutput\x12/\n\trecipient\x18\x01 \x01(\x0b\x32\x1c.eolymp.newsletter.Recipient2\xa4\x07\n\x10RecipientService\x12\xc0\x01\n\x11\x44\x65scribeRecipient\x12).eolymp.newsletter.DescribeRecipientInput\x1a*.eolymp.newsletter.DescribeRecipientOutput\"T\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1c\x12\x1a/recipients/{recipient_id}\x12\xb6\x01\n\x10ImportRecipients\x12(.eolymp.newsletter.ImportRecipientsInput\x1a).eolymp.newsletter.ImportRecipientsOutput\"M\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x15\"\x13/imports/recipients\x12\xa8\x01\n\x0eListRecipients\x12&.eolymp.newsletter.ListRecipientsInput\x1a\'.eolymp.newsletter.ListRecipientsOutput\"E\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\x12\x0b/recipients\x12\xab\x01\n\x0f\x43reateRecipient\x12\'.eolymp.newsletter.CreateRecipientInput\x1a(.eolymp.newsletter.CreateRecipientOutput\"E\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\"\x0b/recipients\x12\xba\x01\n\x0fRemoveRecipient\x12\'.eolymp.newsletter.RemoveRecipientInput\x1a(.eolymp.newsletter.RemoveRecipientOutput\"T\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1c*\x1a/recipients/{recipient_id}B7Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletterb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.newsletter.recipient_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletter'
  _RECIPIENTSERVICE.methods_by_name['DescribeRecipient']._options = None
  _RECIPIENTSERVICE.methods_by_name['DescribeRecipient']._serialized_options = b'\202\343\n\037\212\343\n\033newsletter:newsletter:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\034\022\032/recipients/{recipient_id}'
  _RECIPIENTSERVICE.methods_by_name['ImportRecipients']._options = None
  _RECIPIENTSERVICE.methods_by_name['ImportRecipients']._serialized_options = b'\202\343\n\037\212\343\n\033newsletter:newsletter:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\025\"\023/imports/recipients'
  _RECIPIENTSERVICE.methods_by_name['ListRecipients']._options = None
  _RECIPIENTSERVICE.methods_by_name['ListRecipients']._serialized_options = b'\202\343\n\037\212\343\n\033newsletter:newsletter:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\r\022\013/recipients'
  _RECIPIENTSERVICE.methods_by_name['CreateRecipient']._options = None
  _RECIPIENTSERVICE.methods_by_name['CreateRecipient']._serialized_options = b'\202\343\n\037\212\343\n\033newsletter:newsletter:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\r\"\013/recipients'
  _RECIPIENTSERVICE.methods_by_name['RemoveRecipient']._options = None
  _RECIPIENTSERVICE.methods_by_name['RemoveRecipient']._serialized_options = b'\202\343\n\037\212\343\n\033newsletter:newsletter:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\034*\032/recipients/{recipient_id}'
  _CREATERECIPIENTINPUT._serialized_start=198
  _CREATERECIPIENTINPUT._serialized_end=269
  _CREATERECIPIENTOUTPUT._serialized_start=271
  _CREATERECIPIENTOUTPUT._serialized_end=316
  _IMPORTRECIPIENTSINPUT._serialized_start=318
  _IMPORTRECIPIENTSINPUT._serialized_end=371
  _IMPORTRECIPIENTSOUTPUT._serialized_start=373
  _IMPORTRECIPIENTSOUTPUT._serialized_end=421
  _REMOVERECIPIENTINPUT._serialized_start=423
  _REMOVERECIPIENTINPUT._serialized_end=467
  _REMOVERECIPIENTOUTPUT._serialized_start=469
  _REMOVERECIPIENTOUTPUT._serialized_end=492
  _LISTRECIPIENTSINPUT._serialized_start=494
  _LISTRECIPIENTSINPUT._serialized_end=545
  _LISTRECIPIENTSOUTPUT._serialized_start=547
  _LISTRECIPIENTSOUTPUT._serialized_end=629
  _DESCRIBERECIPIENTINPUT._serialized_start=631
  _DESCRIBERECIPIENTINPUT._serialized_end=677
  _DESCRIBERECIPIENTOUTPUT._serialized_start=679
  _DESCRIBERECIPIENTOUTPUT._serialized_end=753
  _RECIPIENTSERVICE._serialized_start=756
  _RECIPIENTSERVICE._serialized_end=1688
# @@protoc_insertion_point(module_scope)
