# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/user_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.cognito import quota_pb2 as eolymp_dot_cognito_dot_quota__pb2
from eolymp.cognito import user_pb2 as eolymp_dot_cognito_dot_user__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/cognito/user_service.proto\x12\x0e\x65olymp.cognito\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1a\x65olymp/cognito/quota.proto\x1a\x19\x65olymp/cognito/user.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"]\n\x10UserChangedEvent\x12$\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x14.eolymp.cognito.User\x12#\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x14.eolymp.cognito.User\"\x9b\x01\n\x0f\x43reateUserInput\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x11\n\tfull_name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x05 \x01(\t\x12\x10\n\x08\x62irthday\x18\x06 \x01(\t\x12\x0f\n\x07\x63\x61ptcha\x18\n \x01(\t\x12\x0e\n\x06locale\x18\x14 \x01(\t\"D\n\x10\x43reateUserOutput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x02 \x01(\t\"3\n\x10VerifyEmailInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\x13\n\x11VerifyEmailOutput\"\x1e\n\x1cResendEmailVerificationInput\"@\n\x1dResendEmailVerificationOutput\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x01 \x01(\t\"\xdc\x02\n\x12UpdateProfileInput\x12\x37\n\x05patch\x18\x01 \x03(\x0e\x32(.eolymp.cognito.UpdateProfileInput.Patch\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07\x63ompany\x18\x0c \x01(\t\x12\x12\n\noccupation\x18\r \x01(\t\x12\x0f\n\x07\x63ountry\x18\x15 \x01(\t\x12\x0c\n\x04\x63ity\x18\x16 \x01(\t\x12\x10\n\x08\x62irthday\x18! \x01(\t\x12\x0e\n\x06locale\x18\" \x01(\t\"x\n\x05Patch\x12\x0c\n\x08USERNAME\x10\x00\x12\t\n\x05\x45MAIL\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x0b\n\x07\x43OMPANY\x10\x03\x12\x0e\n\nOCCUPATION\x10\x04\x12\x0b\n\x07\x43OUNTRY\x10\x05\x12\x08\n\x04\x43ITY\x10\x06\x12\x0c\n\x08\x42IRTHDAY\x10\x07\x12\n\n\x06LOCALE\x10\x08\"6\n\x13UpdateProfileOutput\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x01 \x01(\t\"f\n\x12UpdatePictureInput\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x10\n\x08offset_x\x18\n \x01(\r\x12\x10\n\x08offset_y\x18\x0b \x01(\r\x12\x0c\n\x04size\x18\x0c \x01(\r\"\x15\n\x13UpdatePictureOutput\"E\n\x13UpdatePasswordInput\x12\x18\n\x10\x63urrent_password\x18\x01 \x01(\t\x12\x14\n\x0cnew_password\x18\x02 \x01(\t\"\x16\n\x14UpdatePasswordOutput\"\x15\n\x13IntrospectUserInput\":\n\x14IntrospectUserOutput\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.eolymp.cognito.User\"$\n\x11\x44\x65scribeUserInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"8\n\x12\x44\x65scribeUserOutput\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.eolymp.cognito.User\"\xd2\x01\n\x0eListUsersInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.cognito.ListUsersInput.Filter\x1aj\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x34\n\x08username\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"E\n\x0fListUsersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.cognito.User\"\x16\n\x14IntrospectQuotaInput\"\xe9\x01\n\x15IntrospectQuotaOutput\x12\x30\n\x11\x63ontests_per_user\x18\n \x01(\x0b\x32\x15.eolymp.cognito.Quota\x12\x33\n\x14problems_per_contest\x18\x0b \x01(\x0b\x32\x15.eolymp.cognito.Quota\x12\x37\n\x18participants_per_contest\x18\x0c \x01(\x0b\x32\x15.eolymp.cognito.Quota\x12\x30\n\x11problems_per_user\x18\x14 \x01(\x0b\x32\x15.eolymp.cognito.Quota\"D\n\x12StartRecoveryInput\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61ptcha\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x14 \x01(\t\"2\n\x13StartRecoveryOutput\x12\x1b\n\x13\x65mail_recovery_hint\x18\x01 \x01(\t\"I\n\x14\x43ompleteRecoverInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\x17\n\x15\x43ompleteRecoverOutput\"\x13\n\x11SelfDestructInput\"C\n\x12SelfDestructOutput\x12-\n\tdelete_on\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xf1\r\n\x0bUserService\x12n\n\nCreateUser\x12\x1f.eolymp.cognito.CreateUserInput\x1a .eolymp.cognito.CreateUserOutput\"\x1d\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x08\"\x06/users\x12\x82\x01\n\x0bVerifyEmail\x12 .eolymp.cognito.VerifyEmailInput\x1a!.eolymp.cognito.VerifyEmailOutput\".\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x01\x82\xd3\xe4\x93\x02\x19\"\x17/users/{user_id}/verify\x12\xae\x01\n\x17ResendEmailVerification\x12,.eolymp.cognito.ResendEmailVerificationInput\x1a-.eolymp.cognito.ResendEmailVerificationOutput\"6\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02!\"\x1f/self/email/resend-verification\x12v\n\rUpdateProfile\x12\".eolymp.cognito.UpdateProfileInput\x1a#.eolymp.cognito.UpdateProfileOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x07\"\x05/self\x12~\n\rUpdatePicture\x12\".eolymp.cognito.UpdatePictureInput\x1a#.eolymp.cognito.UpdatePictureOutput\"$\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0f\"\r/self/picture\x12\x98\x01\n\x0eUpdatePassword\x12#.eolymp.cognito.UpdatePasswordInput\x1a$.eolymp.cognito.UpdatePasswordOutput\";\x82\xe3\n\x12\x8a\xe3\n\x0epassword_grant\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x10\"\x0e/self/password\x12y\n\x0eIntrospectUser\x12#.eolymp.cognito.IntrospectUserInput\x1a$.eolymp.cognito.IntrospectUserOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x07\x12\x05/self\x12\x98\x01\n\x0c\x44\x65scribeUser\x12!.eolymp.cognito.DescribeUserInput\x1a\".eolymp.cognito.DescribeUserOutput\"A\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:user:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HC\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x12\x12\x10/users/{user_id}\x12\x84\x01\n\tListUsers\x12\x1e.eolymp.cognito.ListUsersInput\x1a\x1f.eolymp.cognito.ListUsersOutput\"6\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:user:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00pA\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x08\x12\x06/users\x12\x82\x01\n\x0fIntrospectQuota\x12$.eolymp.cognito.IntrospectQuotaInput\x1a%.eolymp.cognito.IntrospectQuotaOutput\"\"\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\x12\x0b/self/quota\x12\x7f\n\rStartRecovery\x12\".eolymp.cognito.StartRecoveryInput\x1a#.eolymp.cognito.StartRecoveryOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x10\"\x0e/self/recovery\x12\x90\x01\n\x10\x43ompleteRecovery\x12$.eolymp.cognito.CompleteRecoverInput\x1a%.eolymp.cognito.CompleteRecoverOutput\"/\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1a\"\x18/users/{user_id}/recover\x12s\n\x0cSelfDestruct\x12!.eolymp.cognito.SelfDestructInput\x1a\".eolymp.cognito.SelfDestructOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x07*\x05/selfB1Z/github.com/eolymp/go-sdk/eolymp/cognito;cognitob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.cognito.user_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/cognito;cognito'
  _USERSERVICE.methods_by_name['CreateUser']._options = None
  _USERSERVICE.methods_by_name['CreateUser']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\010\"\006/users'
  _USERSERVICE.methods_by_name['VerifyEmail']._options = None
  _USERSERVICE.methods_by_name['VerifyEmail']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\001\202\323\344\223\002\031\"\027/users/{user_id}/verify'
  _USERSERVICE.methods_by_name['ResendEmailVerification']._options = None
  _USERSERVICE.methods_by_name['ResendEmailVerification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002!\"\037/self/email/resend-verification'
  _USERSERVICE.methods_by_name['UpdateProfile']._options = None
  _USERSERVICE.methods_by_name['UpdateProfile']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\007\"\005/self'
  _USERSERVICE.methods_by_name['UpdatePicture']._options = None
  _USERSERVICE.methods_by_name['UpdatePicture']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\017\"\r/self/picture'
  _USERSERVICE.methods_by_name['UpdatePassword']._options = None
  _USERSERVICE.methods_by_name['UpdatePassword']._serialized_options = b'\202\343\n\022\212\343\n\016password_grant\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\020\"\016/self/password'
  _USERSERVICE.methods_by_name['IntrospectUser']._options = None
  _USERSERVICE.methods_by_name['IntrospectUser']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\007\022\005/self'
  _USERSERVICE.methods_by_name['DescribeUser']._options = None
  _USERSERVICE.methods_by_name['DescribeUser']._serialized_options = b'\202\343\n\025\212\343\n\021cognito:user:read\352\342\n\014\365\342\n\000\000HC\370\342\n\364\003\202\323\344\223\002\022\022\020/users/{user_id}'
  _USERSERVICE.methods_by_name['ListUsers']._options = None
  _USERSERVICE.methods_by_name['ListUsers']._serialized_options = b'\202\343\n\025\212\343\n\021cognito:user:read\352\342\n\013\365\342\n\000\000pA\370\342\nd\202\323\344\223\002\010\022\006/users'
  _USERSERVICE.methods_by_name['IntrospectQuota']._options = None
  _USERSERVICE.methods_by_name['IntrospectQuota']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\r\022\013/self/quota'
  _USERSERVICE.methods_by_name['StartRecovery']._options = None
  _USERSERVICE.methods_by_name['StartRecovery']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\005\202\323\344\223\002\020\"\016/self/recovery'
  _USERSERVICE.methods_by_name['CompleteRecovery']._options = None
  _USERSERVICE.methods_by_name['CompleteRecovery']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\032\"\030/users/{user_id}/recover'
  _USERSERVICE.methods_by_name['SelfDestruct']._options = None
  _USERSERVICE.methods_by_name['SelfDestruct']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\007*\005/self'
  _USERCHANGEDEVENT._serialized_start=275
  _USERCHANGEDEVENT._serialized_end=368
  _CREATEUSERINPUT._serialized_start=371
  _CREATEUSERINPUT._serialized_end=526
  _CREATEUSEROUTPUT._serialized_start=528
  _CREATEUSEROUTPUT._serialized_end=596
  _VERIFYEMAILINPUT._serialized_start=598
  _VERIFYEMAILINPUT._serialized_end=649
  _VERIFYEMAILOUTPUT._serialized_start=651
  _VERIFYEMAILOUTPUT._serialized_end=670
  _RESENDEMAILVERIFICATIONINPUT._serialized_start=672
  _RESENDEMAILVERIFICATIONINPUT._serialized_end=702
  _RESENDEMAILVERIFICATIONOUTPUT._serialized_start=704
  _RESENDEMAILVERIFICATIONOUTPUT._serialized_end=768
  _UPDATEPROFILEINPUT._serialized_start=771
  _UPDATEPROFILEINPUT._serialized_end=1119
  _UPDATEPROFILEINPUT_PATCH._serialized_start=999
  _UPDATEPROFILEINPUT_PATCH._serialized_end=1119
  _UPDATEPROFILEOUTPUT._serialized_start=1121
  _UPDATEPROFILEOUTPUT._serialized_end=1175
  _UPDATEPICTUREINPUT._serialized_start=1177
  _UPDATEPICTUREINPUT._serialized_end=1279
  _UPDATEPICTUREOUTPUT._serialized_start=1281
  _UPDATEPICTUREOUTPUT._serialized_end=1302
  _UPDATEPASSWORDINPUT._serialized_start=1304
  _UPDATEPASSWORDINPUT._serialized_end=1373
  _UPDATEPASSWORDOUTPUT._serialized_start=1375
  _UPDATEPASSWORDOUTPUT._serialized_end=1397
  _INTROSPECTUSERINPUT._serialized_start=1399
  _INTROSPECTUSERINPUT._serialized_end=1420
  _INTROSPECTUSEROUTPUT._serialized_start=1422
  _INTROSPECTUSEROUTPUT._serialized_end=1480
  _DESCRIBEUSERINPUT._serialized_start=1482
  _DESCRIBEUSERINPUT._serialized_end=1518
  _DESCRIBEUSEROUTPUT._serialized_start=1520
  _DESCRIBEUSEROUTPUT._serialized_end=1576
  _LISTUSERSINPUT._serialized_start=1579
  _LISTUSERSINPUT._serialized_end=1789
  _LISTUSERSINPUT_FILTER._serialized_start=1683
  _LISTUSERSINPUT_FILTER._serialized_end=1789
  _LISTUSERSOUTPUT._serialized_start=1791
  _LISTUSERSOUTPUT._serialized_end=1860
  _INTROSPECTQUOTAINPUT._serialized_start=1862
  _INTROSPECTQUOTAINPUT._serialized_end=1884
  _INTROSPECTQUOTAOUTPUT._serialized_start=1887
  _INTROSPECTQUOTAOUTPUT._serialized_end=2120
  _STARTRECOVERYINPUT._serialized_start=2122
  _STARTRECOVERYINPUT._serialized_end=2190
  _STARTRECOVERYOUTPUT._serialized_start=2192
  _STARTRECOVERYOUTPUT._serialized_end=2242
  _COMPLETERECOVERINPUT._serialized_start=2244
  _COMPLETERECOVERINPUT._serialized_end=2317
  _COMPLETERECOVEROUTPUT._serialized_start=2319
  _COMPLETERECOVEROUTPUT._serialized_end=2342
  _SELFDESTRUCTINPUT._serialized_start=2344
  _SELFDESTRUCTINPUT._serialized_end=2363
  _SELFDESTRUCTOUTPUT._serialized_start=2365
  _SELFDESTRUCTOUTPUT._serialized_end=2432
  _USERSERVICE._serialized_start=2435
  _USERSERVICE._serialized_end=4212
# @@protoc_insertion_point(module_scope)
