# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/contest_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.judge import activity_pb2 as eolymp_dot_judge_dot_activity__pb2
from eolymp.judge import contest_pb2 as eolymp_dot_judge_dot_contest__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/judge/contest_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/judge/activity.proto\x1a\x1a\x65olymp/judge/contest.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"<\n\x12\x43reateContestInput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\")\n\x13\x43reateContestOutput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"(\n\x12\x44\x65leteContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteContestOutput\"\xcb\x03\n\x12UpdateContestInput\x12\x35\n\x05patch\x18\x03 \x03(\x0e\x32&.eolymp.judge.UpdateContestInput.Patch\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12&\n\x07\x63ontest\x18\x02 \x01(\x0b\x32\x15.eolymp.judge.Contest\"\xc1\x02\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x02\x12\r\n\tSTARTS_AT\x10\x03\x12\x0b\n\x07\x45NDS_AT\x10\x04\x12\x0c\n\x08\x44URATION\x10\x05\x12\x0e\n\nVISIBILITY\x10\x06\x12\x15\n\x11JOIN_UNOFFICIALLY\x10\x07\x12\x16\n\x12PARTICIPATION_MODE\x10\x08\x12\n\n\x06\x46ORMAT\x10\n\x12\x07\n\x03KEY\x10\x0b\x12\x0c\n\x08LOGO_URL\x10\x0e\x12\x18\n\x14PROBLEM_COUNT_HIDDEN\x10\x0c\x12\x1c\n\x18PARTICIPANT_COUNT_HIDDEN\x10\r\x12\x12\n\x0e\x46\x45\x41TURED_UNTIL\x10\t\x12\r\n\x08TAXONOMY\x10\x8c\x01\x12\x0e\n\nAPPEARANCE\x10n\x12\x10\n\x0b\x45NVIRONMENT\x10\x82\x01\x12\x0b\n\x07UPSOLVE\x10x\x12\x0f\n\nSCOREBOARD\x10\x96\x01\"\x15\n\x13UpdateContestOutput\"\x84\x02\n\x10\x43opyContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x38\n\ncopy_scope\x18\x02 \x03(\x0e\x32$.eolymp.judge.CopyContestInput.Scope\x12\x11\n\tcopy_name\x18\x03 \x01(\t\x12\x39\n\x0f\x63opy_visibility\x18\x04 \x01(\x0e\x32 .eolymp.judge.Contest.Visibility\"T\n\x05Scope\x12\x07\n\x03\x41LL\x10\x00\x12\x11\n\rCONFIGURATION\x10\x01\x12\x0c\n\x08PROBLEMS\x10\x02\x12\x10\n\x0cPARTICIPANTS\x10\x03\x12\x0f\n\x0bPERMISSIONS\x10\x04\",\n\x11\x43opyContestOutput\x12\x17\n\x0f\x63opy_contest_id\x18\x01 \x01(\t\"*\n\x14\x44\x65scribeContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"?\n\x15\x44\x65scribeContestOutput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\"\xb2\x07\n\x11ListContestsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.judge.ListContestsInput.Filter\x1a\xc5\x06\n\x06\x46ilter\x12\r\n\x05query\x18\t \x01(\t\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x38\n\tstarts_at\x18\x04 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x36\n\x07\x65nds_at\x18\x05 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x30\n\x06public\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x34\n\nvisibility\x18\x07 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06\x66ormat\x18\x08 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06status\x18\n \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x32\n\x08\x66\x65\x61tured\x18\x0b \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12-\n\x04year\x18\x64 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12/\n\x05scale\x18\x65 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06series\x18\x66 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x33\n\ndifficulty\x18g \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12\x31\n\x07\x63ountry\x18h \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06region\x18i \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x04\x63ity\x18j \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"I\n\x12ListContestsOutput\x12$\n\x05items\x18\x01 \x03(\x0b\x32\x15.eolymp.judge.Contest\x12\r\n\x05total\x18\x02 \x01(\x05\"&\n\x10OpenContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x13\n\x11OpenContestOutput\"\'\n\x11\x43loseContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x14\n\x12\x43loseContestOutput\")\n\x13SuspendContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x16\n\x14SuspendContestOutput\"(\n\x12\x46reezeContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x15\n\x13\x46reezeContestOutput\"(\n\x12ResumeContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x15\n\x13ResumeContestOutput\"\'\n\x11WatchContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"<\n\x12WatchContestOutput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\"G\n\x13ListActivitiesInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"L\n\x14ListActivitiesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.judge.Activity\"}\n\x19\x44\x65scribeContestUsageInput\x12\x30\n\x0cperiod_start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nperiod_end\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"g\n\x1a\x44\x65scribeContestUsageOutput\x12\x16\n\x0etotal_contests\x18\x01 \x01(\r\x12\x17\n\x0f\x61\x63tive_contests\x18\x02 \x01(\r\x12\x18\n\x10monthly_contests\x18\x03 \x01(\r2\xfa\x10\n\x0e\x43ontestService\x12\x91\x01\n\rCreateContest\x12 .eolymp.judge.CreateContestInput\x1a!.eolymp.judge.CreateContestOutput\";\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7\xa3=\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0b\"\t/contests\x12\x9e\x01\n\rDeleteContest\x12 .eolymp.judge.DeleteContestInput\x1a!.eolymp.judge.DeleteContestOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x18*\x16/contests/{contest_id}\x12\x9e\x01\n\rUpdateContest\x12 .eolymp.judge.UpdateContestInput\x1a!.eolymp.judge.UpdateContestOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x18\x1a\x16/contests/{contest_id}\x12\x9d\x01\n\x0b\x43opyContest\x12\x1e.eolymp.judge.CopyContestInput\x1a\x1f.eolymp.judge.CopyContestOutput\"M\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1d\"\x1b/contests/{contest_id}/copy\x12\x89\x01\n\x0f\x44\x65scribeContest\x12\".eolymp.judge.DescribeContestInput\x1a#.eolymp.judge.DescribeContestOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x18\x12\x16/contests/{contest_id}\x12s\n\x0cListContests\x12\x1f.eolymp.judge.ListContestsInput\x1a .eolymp.judge.ListContestsOutput\" \xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0b\x12\t/contests\x12\x9d\x01\n\x0bOpenContest\x12\x1e.eolymp.judge.OpenContestInput\x1a\x1f.eolymp.judge.OpenContestOutput\"M\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1d\"\x1b/contests/{contest_id}/open\x12\xa1\x01\n\x0c\x43loseContest\x12\x1f.eolymp.judge.CloseContestInput\x1a .eolymp.judge.CloseContestOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\"\x1c/contests/{contest_id}/close\x12\xa9\x01\n\x0eSuspendContest\x12!.eolymp.judge.SuspendContestInput\x1a\".eolymp.judge.SuspendContestOutput\"P\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02 \"\x1e/contests/{contest_id}/suspend\x12\xa5\x01\n\rFreezeContest\x12 .eolymp.judge.FreezeContestInput\x1a!.eolymp.judge.FreezeContestOutput\"O\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1f\"\x1d/contests/{contest_id}/freeze\x12\xa5\x01\n\rResumeContest\x12 .eolymp.judge.ResumeContestInput\x1a!.eolymp.judge.ResumeContestOutput\"O\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1f\"\x1d/contests/{contest_id}/resume\x12o\n\x0cWatchContest\x12\x1f.eolymp.judge.WatchContestInput\x1a .eolymp.judge.WatchContestOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\xab\x01\n\x0eListActivities\x12!.eolymp.judge.ListActivitiesInput\x1a\".eolymp.judge.ListActivitiesOutput\"R\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02#\x12!/contests/{contest_id}/activities\x12\x91\x01\n\x14\x44\x65scribeContestUsage\x12\'.eolymp.judge.DescribeContestUsageInput\x1a(.eolymp.judge.DescribeContestUsageOutput\"&\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x11\x12\x0f/usage/contestsB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.contest_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _CONTESTSERVICE.methods_by_name['CreateContest']._options = None
  _CONTESTSERVICE.methods_by_name['CreateContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\n\327\243=\370\342\n\005\202\323\344\223\002\013\"\t/contests'
  _CONTESTSERVICE.methods_by_name['DeleteContest']._options = None
  _CONTESTSERVICE.methods_by_name['DeleteContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\030*\026/contests/{contest_id}'
  _CONTESTSERVICE.methods_by_name['UpdateContest']._options = None
  _CONTESTSERVICE.methods_by_name['UpdateContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\030\032\026/contests/{contest_id}'
  _CONTESTSERVICE.methods_by_name['CopyContest']._options = None
  _CONTESTSERVICE.methods_by_name['CopyContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\035\"\033/contests/{contest_id}/copy'
  _CONTESTSERVICE.methods_by_name['DescribeContest']._options = None
  _CONTESTSERVICE.methods_by_name['DescribeContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\030\022\026/contests/{contest_id}'
  _CONTESTSERVICE.methods_by_name['ListContests']._options = None
  _CONTESTSERVICE.methods_by_name['ListContests']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\013\022\t/contests'
  _CONTESTSERVICE.methods_by_name['OpenContest']._options = None
  _CONTESTSERVICE.methods_by_name['OpenContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\035\"\033/contests/{contest_id}/open'
  _CONTESTSERVICE.methods_by_name['CloseContest']._options = None
  _CONTESTSERVICE.methods_by_name['CloseContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\"\034/contests/{contest_id}/close'
  _CONTESTSERVICE.methods_by_name['SuspendContest']._options = None
  _CONTESTSERVICE.methods_by_name['SuspendContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002 \"\036/contests/{contest_id}/suspend'
  _CONTESTSERVICE.methods_by_name['FreezeContest']._options = None
  _CONTESTSERVICE.methods_by_name['FreezeContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\037\"\035/contests/{contest_id}/freeze'
  _CONTESTSERVICE.methods_by_name['ResumeContest']._options = None
  _CONTESTSERVICE.methods_by_name['ResumeContest']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\037\"\035/contests/{contest_id}/resume'
  _CONTESTSERVICE.methods_by_name['WatchContest']._options = None
  _CONTESTSERVICE.methods_by_name['WatchContest']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _CONTESTSERVICE.methods_by_name['ListActivities']._options = None
  _CONTESTSERVICE.methods_by_name['ListActivities']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002#\022!/contests/{contest_id}/activities'
  _CONTESTSERVICE.methods_by_name['DescribeContestUsage']._options = None
  _CONTESTSERVICE.methods_by_name['DescribeContestUsage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\021\022\017/usage/contests'
  _CREATECONTESTINPUT._serialized_start=276
  _CREATECONTESTINPUT._serialized_end=336
  _CREATECONTESTOUTPUT._serialized_start=338
  _CREATECONTESTOUTPUT._serialized_end=379
  _DELETECONTESTINPUT._serialized_start=381
  _DELETECONTESTINPUT._serialized_end=421
  _DELETECONTESTOUTPUT._serialized_start=423
  _DELETECONTESTOUTPUT._serialized_end=444
  _UPDATECONTESTINPUT._serialized_start=447
  _UPDATECONTESTINPUT._serialized_end=906
  _UPDATECONTESTINPUT_PATCH._serialized_start=585
  _UPDATECONTESTINPUT_PATCH._serialized_end=906
  _UPDATECONTESTOUTPUT._serialized_start=908
  _UPDATECONTESTOUTPUT._serialized_end=929
  _COPYCONTESTINPUT._serialized_start=932
  _COPYCONTESTINPUT._serialized_end=1192
  _COPYCONTESTINPUT_SCOPE._serialized_start=1108
  _COPYCONTESTINPUT_SCOPE._serialized_end=1192
  _COPYCONTESTOUTPUT._serialized_start=1194
  _COPYCONTESTOUTPUT._serialized_end=1238
  _DESCRIBECONTESTINPUT._serialized_start=1240
  _DESCRIBECONTESTINPUT._serialized_end=1282
  _DESCRIBECONTESTOUTPUT._serialized_start=1284
  _DESCRIBECONTESTOUTPUT._serialized_end=1347
  _LISTCONTESTSINPUT._serialized_start=1350
  _LISTCONTESTSINPUT._serialized_end=2296
  _LISTCONTESTSINPUT_FILTER._serialized_start=1459
  _LISTCONTESTSINPUT_FILTER._serialized_end=2296
  _LISTCONTESTSOUTPUT._serialized_start=2298
  _LISTCONTESTSOUTPUT._serialized_end=2371
  _OPENCONTESTINPUT._serialized_start=2373
  _OPENCONTESTINPUT._serialized_end=2411
  _OPENCONTESTOUTPUT._serialized_start=2413
  _OPENCONTESTOUTPUT._serialized_end=2432
  _CLOSECONTESTINPUT._serialized_start=2434
  _CLOSECONTESTINPUT._serialized_end=2473
  _CLOSECONTESTOUTPUT._serialized_start=2475
  _CLOSECONTESTOUTPUT._serialized_end=2495
  _SUSPENDCONTESTINPUT._serialized_start=2497
  _SUSPENDCONTESTINPUT._serialized_end=2538
  _SUSPENDCONTESTOUTPUT._serialized_start=2540
  _SUSPENDCONTESTOUTPUT._serialized_end=2562
  _FREEZECONTESTINPUT._serialized_start=2564
  _FREEZECONTESTINPUT._serialized_end=2604
  _FREEZECONTESTOUTPUT._serialized_start=2606
  _FREEZECONTESTOUTPUT._serialized_end=2627
  _RESUMECONTESTINPUT._serialized_start=2629
  _RESUMECONTESTINPUT._serialized_end=2669
  _RESUMECONTESTOUTPUT._serialized_start=2671
  _RESUMECONTESTOUTPUT._serialized_end=2692
  _WATCHCONTESTINPUT._serialized_start=2694
  _WATCHCONTESTINPUT._serialized_end=2733
  _WATCHCONTESTOUTPUT._serialized_start=2735
  _WATCHCONTESTOUTPUT._serialized_end=2795
  _LISTACTIVITIESINPUT._serialized_start=2797
  _LISTACTIVITIESINPUT._serialized_end=2868
  _LISTACTIVITIESOUTPUT._serialized_start=2870
  _LISTACTIVITIESOUTPUT._serialized_end=2946
  _DESCRIBECONTESTUSAGEINPUT._serialized_start=2948
  _DESCRIBECONTESTUSAGEINPUT._serialized_end=3073
  _DESCRIBECONTESTUSAGEOUTPUT._serialized_start=3075
  _DESCRIBECONTESTUSAGEOUTPUT._serialized_end=3178
  _CONTESTSERVICE._serialized_start=3181
  _CONTESTSERVICE._serialized_end=5351
# @@protoc_insertion_point(module_scope)
