from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

COMPLETE: FeedbackPolicy
DESCRIPTOR: _descriptor.FileDescriptor
ICPC: FeedbackPolicy
ICPC_EXPANDED: FeedbackPolicy

class FeedbackPolicy(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
