# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/configuration_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import configuration_identity_pb2 as eolymp_dot_community_dot_configuration__identity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,eolymp/community/configuration_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a-eolymp/community/configuration_identity.proto\"\x1d\n\x1b\x44\x65scribeIdentityConfigInput\"P\n\x1c\x44\x65scribeIdentityConfigOutput\x12\x30\n\x06\x63onfig\x18\x01 \x01(\x0b\x32 .eolymp.community.IdentityConfig\"P\n\x1c\x43onfigureIdentityConfigInput\x12\x30\n\x06\x63onfig\x18\x01 \x01(\x0b\x32 .eolymp.community.IdentityConfig\"\x1f\n\x1d\x43onfigureIdentityConfigOutput2\xff\x02\n\x14\x43onfigurationService\x12\xa1\x01\n\x16\x44\x65scribeIdentityConfig\x12-.eolymp.community.DescribeIdentityConfigInput\x1a..eolymp.community.DescribeIdentityConfigOutput\"(\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x13\x12\x11/configs/identity\x12\xc2\x01\n\x17\x43onfigureIdentityConfig\x12..eolymp.community.ConfigureIdentityConfigInput\x1a/.eolymp.community.ConfigureIdentityConfigOutput\"F\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x13\x1a\x11/configs/identityB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.configuration_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _CONFIGURATIONSERVICE.methods_by_name['DescribeIdentityConfig']._options = None
  _CONFIGURATIONSERVICE.methods_by_name['DescribeIdentityConfig']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\023\022\021/configs/identity'
  _CONFIGURATIONSERVICE.methods_by_name['ConfigureIdentityConfig']._options = None
  _CONFIGURATIONSERVICE.methods_by_name['ConfigureIdentityConfig']._serialized_options = b'\202\343\n\032\212\343\n\026community:member:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\023\032\021/configs/identity'
  _DESCRIBEIDENTITYCONFIGINPUT._serialized_start=212
  _DESCRIBEIDENTITYCONFIGINPUT._serialized_end=241
  _DESCRIBEIDENTITYCONFIGOUTPUT._serialized_start=243
  _DESCRIBEIDENTITYCONFIGOUTPUT._serialized_end=323
  _CONFIGUREIDENTITYCONFIGINPUT._serialized_start=325
  _CONFIGUREIDENTITYCONFIGINPUT._serialized_end=405
  _CONFIGUREIDENTITYCONFIGOUTPUT._serialized_start=407
  _CONFIGUREIDENTITYCONFIGOUTPUT._serialized_end=438
  _CONFIGURATIONSERVICE._serialized_start=441
  _CONFIGURATIONSERVICE._serialized_end=824
# @@protoc_insertion_point(module_scope)
